@@ -19,8 +19,7 @@
 
 # Standard library imports
 import os
-import sys, site
-from sysconfig import get_path  # new in python 3.2
+import sys
 import time
 import datetime
 from multiprocessing import cpu_count
@@ -41,7 +40,18 @@ from sfalmanac.lib.eventtables import maketables as maketables
 from sfalmanac.lib.increments import makelatex as makelatex
 
 
+def deletePDF(filename):
+    if os.path.exists(filename + ".pdf"):
+        try:
+            os.remove(filename + ".pdf")
+        except PermissionError:
+            print("ERROR: please close '{}' so it can be re-created".format(filename + ".pdf"))
+            sys.exit(0)
+    if os.path.exists(filename + ".tex"):
+        os.remove(filename + ".tex")
+
 def makePDF(args, fn, msg = ""):
+    print()     # blank line before "This is pdfTex, Version 3.141592653...
     command = 'pdflatex {}'.format(args + fn + ".tex")
     if args == "":
         os.system(command)
@@ -58,11 +68,11 @@ def makePDF(args, fn, msg = ""):
             if msg != "":
                 print("finished" + msg)
             else:
-                print("finished creating PDF")
+                print("finished creating '{}'".format(fn + ".pdf"))
     return
 
-def tidy_up(kl, fn):
-    os.remove(fn + ".tex")
+def tidy_up(fn, kl, kt):
+    if not kt: os.remove(fn + ".tex")
     if not kl:
         if os.path.isfile(fn + ".log"):
             os.remove(fn + ".log")
@@ -70,6 +80,47 @@ def tidy_up(kl, fn):
         os.remove(fn + ".aux")
     return
 
+def check_mth(mm):
+    if not 1 <= int(mm) <= 12:
+        print("ERROR: Enter month between 01 and 12")
+        sys.exit()
+
+def check_date(year, month, day):
+    yy = int(year)
+    mm = int(month)
+    day_count_for_month = [0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]
+    if yy%4==0 and (yy%100 != 0 or yy%400==0):
+        day_count_for_month[2] = 29
+    if not (1 <= mm <= 12 and 1 <= int(day) <= day_count_for_month[mm]):
+        print("ERROR: Enter a valid date")
+        sys.exit()
+
+def check_years(yearfr, yearto):
+    global yrmin, yrmax
+
+    if str(yearfr).isnumeric():
+        if yrmin <= int(yearfr) <= yrmax:
+            first_day = datetime.date(int(yearfr), 1, 1)
+        else:
+            print("!! Please pick a year between {} and {} !!".format(yrmin,yrmax))
+            sys.exit(0)
+    else:
+        print("Error! First year is not numeric")
+        sys.exit(0)
+
+    if str(yearto).isnumeric():
+        if yrmin <= int(yearto) <= yrmax:
+            first_day_to = datetime.date(int(yearto), 1, 1)
+        else:
+            print("!! Please pick a year between {} and {} !!".format(yrmin,yrmax))
+            sys.exit(0)
+        if int(yearto) < int(yearfr):
+            print("Error! The LAST year must be later than the FIRST year")
+            sys.exit(0)
+    else:
+        print("Error! Last year is not numeric")
+        sys.exit(0)
+
 def timer_start():
     # initialize these counts before processing the next year (Almanac or Event Tables)
     config.stopwatch  = 0.0     # 00000
@@ -86,10 +137,13 @@ def timer_end(start, x = 0):
     #print("start = {}".format(time.localtime(start)))
     #print("stop  = {}".format(time.localtime(stop)))
     msg = "execution time = {:0.2f} seconds".format(stop-start)
-    if x == 0: msg += "\n"
+    if x < 0:
+        msg += "\n"     # newline after "execution time = ..."
+        x = abs(x)
     print(msg)
     if config.logfileopen: config.writeLOG("\n\n" + msg)
     if x == 0: return
+
     pct = 100 * config.stopwatch/(stop-start)
     msg4 = " ({:0.1f}%)".format(pct) if not config.MULTIpr else ""
     msg2 = "stopwatch      = {:0.2f} seconds".format(config.stopwatch) + msg4
@@ -99,7 +153,8 @@ def timer_end(start, x = 0):
     #if x == 2: msg3 += "\n"
     if config.logfileopen: config.writeLOG(msg3 + "\n")
     print(msg3)                 # 00000
-    #if x == 2: return   # following is not required for Event Time tables
+
+    if x == 1: return   # following is not required for Event Time tables
     msg5 = "stopwatch2     = {:0.2f} seconds".format(config.stopwatch2)
     print(msg5)                 # 00000
     msg6 = "(stopwatch2 = time spent searching if moon above/below horizon)"
@@ -111,12 +166,12 @@ def search_stats():
     if config.MULTIpr:
         msg4 = "Moonrise/moonset time seeks  = {}".format(config.moonDataSeeks)
         print(msg4)
-        msg5 = "Above/below horizon searches = {}\n".format(config.moonHorizonSeeks)
+        msg5 = "Above/below horizon searches = {}".format(config.moonHorizonSeeks)
         print(msg5)
     else:
         msg4 = "Moonrise/moonset times found in transient store = {} of {}".format(config.moonDataFound, config.moonDataSeeks)
         print(msg4)
-        msg5 = "Moon continuously above/below horizon state found in transient store = {} of {}\n".format(config.moonHorizonFound, config.moonHorizonSeeks)
+        msg5 = "Moon continuously above/below horizon state found in transient store = {} of {}".format(config.moonHorizonFound, config.moonHorizonSeeks)
         print(msg5)
     return
 
@@ -132,7 +187,7 @@ def checkCoreCount():       # only called when config.MULTIpr == True
         config.MULTIpr = False
         print("\nERROR: 2 logical processors minimum are required for parallel processessing")
         print("       defaulting to single processessing")
-    if config.CPUcores < 8 or (not config.WINpf and config.CPUcores < 12):
+    if config.CPUcores < 12 or (config.WINpf and config.CPUcores < 8):
         print("\nNOTE: only {} logical processors are available for parallel processessing".format(config.CPUcores))
 
 
@@ -145,19 +200,23 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
         arg = sys.argv[1]
     except IndexError:
         arg = ""
-    if len(sys.argv) > 2 or not (arg == "" or arg == "-v" or arg == "-log"):
+    if len(sys.argv) > 2 or not (arg == "" or arg == "-v" or arg == "-log" or arg == "-tex"):
         print("One optional command line parameter is permitted:")
-        print(" python -m skyalmanac -v")
+        print(" python sfalmanac.py -v")
         print(" ... to send pdfTeX output to the terminal")
-        print(" python -m skyalmanac -log")
+        print(" python sfalmanac.py -log")
         print(" ... to keep the log file")
+        print(" python sfalmanac.py -tex")
+        print(" ... to keep the tex file")
         sys.exit(0)
 
     args = "" if arg == "-v" else "-interaction=batchmode -halt-on-error "
     keeplog = True if arg == "-log" else False
+    keeptex = True if arg == "-tex" else False
 
     d = datetime.datetime.utcnow().date()
     first_day = datetime.date(d.year, d.month, d.day)
+    yy = "%s" % d.year
 
     # if this code runs locally (not in Docker), the settings in config.py are used.
     # if this code runs in Docker without use of an environment file, the settings in config.py apply.
@@ -166,7 +225,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     ephERR = False
     if config.dockerized:
         docker_main = os.getcwd()
-        spad = docker_main + "/astro-data/"
+        #spad = docker_main + "/astro-data/"
         config.pgsz = os.getenv('PGSZ', config.pgsz)
         config.moonimg = os.getenv('MOONIMG', str(config.moonimg))
         config.ephndx = os.getenv('EPHNDX', str(config.ephndx))
@@ -197,7 +256,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     else:
         #first_day = datetime.date(2023, 6, 24)	## for testing a specific date ##
         #d = first_day							## for testing a specific date ##
-        spad = "./"
+        #spad = "./"
         if config.ephndx not in set([0, 1, 2, 3, 4]):
             ephERR = True
         config.moonimg = str(config.moonimg)
@@ -227,11 +286,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
         print("Please choose a positive non-zero numeric value {}".format(err4))
         sys.exit(0)
 
-    sday = "{:02d}".format(d.day)       # sday = "%02d" % d.day
-    smth = "{:02d}".format(d.month)     # smth = "%02d" % d.month
-    syr  = "{}".format(d.year)          # syr  = "%s" % d.year
-    symd = syr + smth + sday
-    sdmy = sday + "." + smth + "." + syr
+    global yrmin, yrmax
     yrmin = config.ephemeris[config.ephndx][1]
     yrmax = config.ephemeris[config.ephndx][2]
     config.moonimg = (config.moonimg.lower() == 'true') # to boolean
@@ -239,6 +294,8 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     f_prefix = config.docker_prefix
     f_postfix = config.docker_postfix
 
+    # ------------ code for PyPI version ------------
+
     mfp = sys.modules['__main__'].__file__  # main module filepath
     pkg = mfp.split(os.path.sep)[-2]        # this package name
 
@@ -271,10 +328,12 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     print(" Path to config.py:  {}".format(spcf))
     print(" Downloaded data in: {}".format(spad))
 
-    s = input("""\nWhat do you want to create?:\n
-    1   Nautical Almanac   (for a year)
-    2   Sun tables only    (for a year)
-    3   Event Time tables  (for a year)
+    # ------------ process user input ------------
+
+    s = input("""\n  What do you want to create?:\n
+    1   Nautical Almanac   (for a day/month/year)
+    2   Sun tables only    (for a day/month/year)
+    3   Event Time tables  (for a day/month/year)
     4   Nautical almanac   -  6 days from today
     5   Sun tables only    - 30 days from today
     6   Event Time tables  -  6 days from today
@@ -283,50 +342,98 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
 
     if s in set(['1', '2', '3', '4', '5', '6', '7']):
         if int(s) < 4:
-            print("Please enter the desired year")
-            years = input("  as yyyy ... or the FIRST and LAST year as yyyy-yyyy\n")
-            if len(years)== 4:
-                yearfr = years
-                yearto = years
-            elif len(years) == 9 and years[4] == '-':
-                yearfr = years[0:4]
-                yearto = years[5:9]
-            else:
-                print("Error! Invalid format")
-                sys.exit(0)
-            
-            if str(yearfr).isnumeric():
-                if yrmin <= int(yearfr) <= yrmax:
-                    first_day = datetime.date(int(yearfr), 1, 1)
-                else:
-                    print("!! Please pick a year between {} and {} !!".format(yrmin,yrmax))
-                    sys.exit(0)
-            else:
-                print("Error! First year is not numeric")
-                sys.exit(0)
+            daystoprocess = 0
+            ss = input("""  Enter as numeric digits:\n
+    - starting date as 'DDMMYYYY'
+    - or just 'YYYY' (for a whole year)
+    - or 'YYYY-YYYY' (for first and last year)
+    - or just 'MM' (01 - 12) for the current or a future month
+    - or '-MM' for a previous month (e.g. '-02' is last February)
+    - nothing for the current day
+""")
+            sErr = False    # syntax error
+            entireMth = False
+            entireYr  = False
 
-            if str(yearto).isnumeric():
-                if yrmin <= int(yearto) <= yrmax:
-                    first_day_to = datetime.date(int(yearto), 1, 1)
-                else:
-                    print("!! Please pick a year between {} and {} !!".format(yrmin,yrmax))
-                    sys.exit(0)
-                if int(yearto) < int(yearfr):
-                    print("Error! The LAST year must be later than the FIRST year")
+            if len(ss) == 0:
+                daystoprocess = 1
+                if d.year > yrmax:
+                    print("!! Only years up to {} are valid!!".format(yrmax))
                     sys.exit(0)
             else:
-                print("Error! Last year is not numeric")
-                sys.exit(0)
+                if len(ss) not in [2,3,4,8,9]: sErr = True
+                if len(ss) == 3:
+                    if ss[0] != '-': sErr = True
+                    if not ss[1:].isnumeric(): sErr = True
+                elif len(ss) == 9:
+                    if ss[4] != '-': sErr = True
+                    if not (ss[:4].isnumeric() and ss[5:].isnumeric()): sErr = True
+                elif not ss.isnumeric(): sErr = True
+
+                if sErr:
+                    print("ERROR: Enter numeric digits in the correct format")
+                    sys.exit()
+
+                if len(ss) == 2:
+                    entireMth = True
+                    dd = "01"
+                    mm = ss[0:2]
+                    check_mth(mm)
+                    if int(mm) < d.month: yy = str(d.year + 1)
+                elif len(ss) == 3:
+                    entireMth = True
+                    dd = "01"
+                    mm = ss[1:3]
+                    check_mth(mm)
+                    if int(mm) >= d.month: yy = str(d.year - 1)
+                elif len(ss) == 4:
+                    entireYr = True
+                    dd = "01"
+                    mm = "01"
+                    yy = ss
+                    yearfr = ss
+                    yearto = ss
+                    check_years(yearfr, yearto)
+                elif len(ss) == 9 and ss[4] == '-':
+                    entireYr = True
+                    dd = "01"
+                    mm = "01"
+                    yy = ss[0:4]
+                    yearfr = ss[0:4]
+                    yearto = ss[5:]
+                    check_years(yearfr, yearto)
+                elif len(ss) == 8:
+                    dd = ss[:2]
+                    mm = ss[2:4]
+                    check_mth(mm)
+                    yy = ss[4:]
+                    check_date(yy,mm,dd)
+                
+                first_day = datetime.date(int(yy), int(mm), int(dd))
+                d = first_day
+
+                if not entireYr and not entireMth and daystoprocess == 0:
+                    daystoprocess = 1       # default
+                    nn = input("""  Enter number of days to process from starting date:
+""")
+                    if len(nn) > 0:
+                        if not nn.isnumeric():
+                            print("ERROR: Not a number")
+                            sys.exit()
+                        daystoprocess = int(nn)
+                        if daystoprocess > 300:
+                            print("ERROR: 'Days to process' not <= 300")
+                            sys.exit()
 
         if s != '3' and int(s) <= 5:
-            tsin = input("""What table style is required?:\n
-        t   Traditional
-        m   Modern
+            tsin = input("""  What table style is required?:\n
+    t   Traditional
+    m   Modern
 """)
             ff = '_'
             DecFmt = ''
             config.tbls = tsin[0:1]	# table style
-            config.decf = tsin[1:2]	# Declination format
+            config.decf = tsin[1:2]	# Declination format ('+' or nothing)
             if config.tbls != 'm':
                 config.tbls = ''		# anything other than 'm' is traditional
                 ff = ''
@@ -335,8 +442,16 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
             else:
                 DecFmt = '[old]'
 
+        sday = "{:02d}".format(d.day)       # sday = "%02d" % d.day
+        smth = "{:02d}".format(d.month)     # smth = "%02d" % d.month
+        syr  = "{}".format(d.year)          # syr  = "%s" % d.year
+        symd = syr + smth + sday
+        sdmy = sday + "." + smth + "." + syr
         #print(datetime.datetime.now().time())
-        if s == '1':        # Nautical Almanac (for a year)
+
+    # ------------ create the desired tables ------------
+
+        if s == '1' and entireYr:        # Nautical Almanac (for a year)
             print("Take a break - this computer needs some time for cosmic meditation.")
     ##        config.initLOG()		# initialize log file
             for yearint in range(int(yearfr),int(yearto)+1):
@@ -351,36 +466,126 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                 print(msg)
     ##            config.writeLOG(msg)
                 first_day = datetime.date(yearint, 1, 1)
-                ff = "tradna_" if config.tbls != 'm' else "modna_"
+                ff = "NAtrad_" if config.tbls != 'm' else "NAmod_"
                 fn = "{}{}".format(ff,year+DecFmt)
+                deletePDF(f_prefix + fn)
                 outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
-                outfile.write(almanac(first_day,122,ts,spad,df180,df360,dfcm))
+                outfile.write(almanac(first_day,0,ts,spad,df180,df360,dfcm))
                 outfile.close()
                 timer_end(start, 1)
                 search_stats()
                 if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-                makePDF(args, fn, " creating nautical almanac for {}".format(year))
-                tidy_up(keeplog, fn)
+                makePDF(args, fn)
+                tidy_up(fn, keeplog, keeptex)
                 if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
     ##        config.closeLOG()     # close log after the for-loop
 
-        elif s == '2':      # Sun Tables (for a year)
+        elif s == '1' and entireMth:        # Nautical Almanac (for a month)
+    ##        config.initLOG()		# initialize log file
+            if config.MULTIpr: checkCoreCount()
+            start = timer_start()
+            config.moonDataSeeks = 0
+            config.moonDataFound = 0
+            config.moonHorizonSeeks = 0
+            config.moonHorizonFound = 0
+            msg = "\nCreating the nautical almanac for {}".format(first_day.strftime("%B %Y"))
+            print(msg)
+    ##            config.writeLOG(msg)
+            ff = "NAtrad_" if config.tbls != 'm' else "NAmod_"
+            fn = "{}{}".format(ff,syr + '-' + smth + DecFmt)
+            deletePDF(f_prefix + fn)
+            outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
+            outfile.write(almanac(first_day,-1,ts,spad,df180,df360,dfcm))
+            outfile.close()
+            timer_end(start, 1)
+            search_stats()
+            if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
+            makePDF(args, fn)
+            tidy_up(fn, keeplog, keeptex)
+            if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
+    ##        config.closeLOG()     # close log after the for-loop
+
+        elif s == '1' and not entireYr and not entireMth:       # Nautical Almanac (for a few days)
+    ##        config.initLOG()		# initialize log file
+            if config.MULTIpr: checkCoreCount()
+            start = timer_start()
+            config.moonDataSeeks = 0
+            config.moonDataFound = 0
+            config.moonHorizonSeeks = 0
+            config.moonHorizonFound = 0
+            txt = "from" if daystoprocess > 1 else "for"
+            msg = "\nCreating the nautical almanac {} {}".format(txt,first_day.strftime("%d %B %Y"))
+            print(msg)
+    ##            config.writeLOG(msg)
+            ff = "NAtrad_" if config.tbls != 'm' else "NAmod_"
+            dto = ""
+            if daystoprocess > 1:   # filename as 'from date'-'to date'
+                lastdate = d + datetime.timedelta(days=daystoprocess-1)
+                dto = lastdate.strftime("-%Y%m%d")
+            fn = "{}".format(ff+symd+dto+DecFmt)
+            deletePDF(f_prefix + fn)
+            outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
+            outfile.write(almanac(first_day,daystoprocess,ts,spad,df180,df360,dfcm))
+            outfile.close()
+            timer_end(start, 1)
+            search_stats()
+            if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
+            makePDF(args, fn)
+            tidy_up(fn, keeplog, keeptex)
+            if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
+    ##        config.closeLOG()     # close log after the for-loop
+
+        elif s == '2' and entireYr:     # Sun Tables (for a year)
             for yearint in range(int(yearfr),int(yearto)+1):
                 year = "{:4d}".format(yearint)  # year = "%4d" %yearint
-                msg = "\nCreating the sun tables for the year {}\n".format(year)
+                msg = "\nCreating the sun tables for the year {}".format(year)
                 print(msg)
                 first_day = datetime.date(yearint, 1, 1)
-                ff = "tradst_" if config.tbls != 'm' else "modst_"
+                ff = "STtrad_" if config.tbls != 'm' else "STmod_"
                 fn = "{}{}".format(ff,year+DecFmt)
+                deletePDF(f_prefix + fn)
                 outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
-                outfile.write(sunalmanac(first_day,25,dfra))
+                outfile.write(sunalmanac(first_day,0,dfra))
                 outfile.close()
                 if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-                makePDF(args, fn, " creating sun tables for {}".format(year))
-                tidy_up(keeplog, fn)
+                makePDF(args, fn)
+                tidy_up(fn, keeplog, keeptex)
                 if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
 
-        elif s == '3':      # Event Time tables  (for a year)
+        elif s == '2' and entireMth:     # Sun Tables (for a month)
+            msg = "\nCreating the sun tables for {}".format(first_day.strftime("%B %Y"))
+            print(msg)
+            ff = "STtrad_" if config.tbls != 'm' else "STmod_"
+            fn = "{}{}".format(ff,syr + '-' + smth + DecFmt)
+            deletePDF(f_prefix + fn)
+            outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
+            outfile.write(sunalmanac(first_day,-1,dfra))
+            outfile.close()
+            if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
+            makePDF(args, fn)
+            tidy_up(fn, keeplog, keeptex)
+            if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
+
+        elif s == '2' and not entireYr and not entireMth:   # Sun Tables (for a few days)
+            txt = "from" if daystoprocess > 1 else "for"
+            msg = "\nCreating the sun tables {} {}".format(txt,first_day.strftime("%d %B %Y"))
+            print(msg)
+            ff = "STtrad_" if config.tbls != 'm' else "STmod_"
+            dto = ""
+            if daystoprocess > 1:   # filename as 'from date'-'to date'
+                lastdate = d + datetime.timedelta(days=daystoprocess-1)
+                dto = lastdate.strftime("-%Y%m%d")
+            fn = "{}".format(ff+symd+dto+DecFmt)
+            deletePDF(f_prefix + fn)
+            outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
+            outfile.write(sunalmanac(first_day,daystoprocess,dfra))
+            outfile.close()
+            if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
+            makePDF(args, fn)
+            tidy_up(fn, keeplog, keeptex)
+            if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
+
+        elif s == '3' and entireYr:      # Event Time tables  (for a year)
             print("Take a break - this computer needs some time for cosmic meditation.")
             for yearint in range(int(yearfr),int(yearto)+1):
                 if config.MULTIpr: checkCoreCount()
@@ -389,27 +594,66 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                 msg = "\nCreating the event time tables for the year {}".format(year)
                 print(msg)
                 first_day = datetime.date(yearint, 1, 1)
-                fn = "event-times_{}".format(year)
+                fn = "Event-Times_{}".format(year)
+                deletePDF(f_prefix + fn)
                 outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
-                outfile.write(maketables(first_day,183,ts,spad,df180,df360))
+                outfile.write(maketables(first_day,0,ts,spad,df180,df360))
                 outfile.close()
-                timer_end(start, 2)
-                print()
+                timer_end(start, 1)
                 if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
-                makePDF(args, fn, " creating event time tables for {}".format(year))
-                tidy_up(keeplog, fn)
+                makePDF(args, fn)
+                tidy_up(fn, keeplog, keeptex)
                 if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
 
+        elif s == '3' and entireMth:      # Event Time tables  (for a month)
+            if config.MULTIpr: checkCoreCount()
+            start = timer_start()
+            msg = "\nCreating the event time tables for {}".format(first_day.strftime("%B %Y"))
+            print(msg)
+            fn = "Event-Times_{}".format(syr + '-' + smth)
+            deletePDF(f_prefix + fn)
+            outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
+            outfile.write(maketables(first_day,-1,ts,spad,df180,df360))
+            outfile.close()
+            timer_end(start, 1)
+            if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
+            makePDF(args, fn)
+            tidy_up(fn, keeplog, keeptex)
+            if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
+
+        elif s == '3' and not entireYr and not entireMth:   # Event Time tables (for a few days)
+            if config.MULTIpr: checkCoreCount()
+            start = timer_start()
+            txt = "from" if daystoprocess > 1 else "for"
+            msg = "\nCreating the event time tables {} {}".format(txt,first_day.strftime("%d %B %Y"))
+            print(msg)
+            fn = "Event-Times_{}".format(symd)
+            if daystoprocess > 1:   # filename as 'from date'-'to date'
+                lastdate = d + datetime.timedelta(days=daystoprocess-1)
+                fn += lastdate.strftime("-%Y%m%d")
+            deletePDF(f_prefix + fn)
+            outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
+            outfile.write(maketables(first_day,daystoprocess,ts,spad,df180,df360))
+            outfile.close()
+            timer_end(start, 1)
+            if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
+            makePDF(args, fn)
+            tidy_up(fn, keeplog, keeptex)
+            if config.dockerized: os.chdir(docker_main)     # reset working folder to code folder
+
         elif s == '4':      # Nautical almanac   -  6 days from today
     ##        config.initLOG()		# initialize log file
             if config.MULTIpr: checkCoreCount()
             start = timer_start()
-            msg = "\nCreating nautical almanac tables - from {}\n".format(sdmy)
+            msg = "\nCreating nautical almanac tables - from {}".format(sdmy)
             print(msg)
-            ff = "tradna_" if config.tbls != 'm' else "modna_"
-            fn = "{}{}".format(ff,symd+DecFmt)
+            ff = "NAtrad_" if config.tbls != 'm' else "NAmod_"
+            fn = "{}".format(ff+symd)
+            lastdate = d + datetime.timedelta(days=5)
+            fn += lastdate.strftime("-%Y%m%d") + DecFmt
+            deletePDF(f_prefix + fn)
             outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
-            outfile.write(almanac(first_day,2,ts,spad,df180,df360,dfcm))
+            outfile.write(almanac(first_day,6,ts,spad,df180,df360,dfcm))
             outfile.close()
             timer_end(start, 1)
             search_stats()
@@ -417,44 +661,51 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
     ##        config.closeLOG()
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
             makePDF(args, fn)
-            tidy_up(keeplog, fn)
+            tidy_up(fn, keeplog, keeptex)
 
         elif s == '5':      # Sun tables only    - 30 days from today
-            msg = "\nCreating the sun tables - from {}\n".format(sdmy)
+            msg = "\nCreating the sun tables - from {}".format(sdmy)
             print(msg)
-            ff = "tradst_" if config.tbls != 'm' else "modst_"
-            fn = "{}{}".format(ff,symd+DecFmt)
+            ff = "STtrad_" if config.tbls != 'm' else "STmod_"
+            fn = "{}".format(ff+symd)
+            lastdate = d + datetime.timedelta(days=29)
+            fn += lastdate.strftime("-%Y%m%d") + DecFmt
+            deletePDF(f_prefix + fn)
             outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
-            outfile.write(sunalmanac(first_day,2,dfra))
+            outfile.write(sunalmanac(first_day,30,dfra))
             outfile.close()
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
             makePDF(args, fn)
-            tidy_up(keeplog, fn)
+            tidy_up(fn, keeplog, keeptex)
 
         elif s == '6':      # Event Time tables  -  6 days from today
             if config.MULTIpr: checkCoreCount()
             start = timer_start()
-            msg = "\nCreating event time tables - from {}\n".format(sdmy)
+            msg = "\nCreating event time tables - from {}".format(sdmy)
             print(msg)
-            fn = "event-times_{}".format(symd)
+            fn = "Event-Times_{}".format(symd)
+            lastdate = d + datetime.timedelta(days=5)
+            fn += lastdate.strftime("-%Y%m%d")
+            deletePDF(f_prefix + fn)
             outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
-            outfile.write(maketables(first_day,3,ts,spad,df180,df360))
+            outfile.write(maketables(first_day,6,ts,spad,df180,df360))
             outfile.close()
-            timer_end(start, 2)
+            timer_end(start, 1)
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
             makePDF(args, fn)
-            tidy_up(keeplog, fn)
+            tidy_up(fn, keeplog, keeptex)
 
         elif s == '7':
-            msg = "\nCreating the Increments and Corrections tables\n"
+            msg = "\nCreating the Increments and Corrections tables"
             print(msg)
-            fn = "inc"
+            fn = "Inc"
+            deletePDF(f_prefix + fn)
             outfile = open(f_prefix + fn + ".tex", mode="w", encoding="utf8")
             outfile.write(makelatex())
             outfile.close()
             if config.dockerized: os.chdir(os.getcwd() + f_postfix)     # DOCKER ONLY
             makePDF(args, fn)
-            tidy_up(keeplog, fn)
+            tidy_up(fn, keeplog, keeptex)
 
     else:
         print("Error! Choose 1, 2, 3, 4, 5, 6 or 7")
