@@ -209,6 +209,7 @@ def mp_planetstransit(d, ts, spad, obj, round2seconds = False):  # used in stars
         else:
             planet = eph['mars']
 
+
     # calculate planet SHA
     tfr = ts.ut1(d.year, d.month, d.day, 0, 0, 0)       # search from
     position = earth.at(tfr).observe(planet)
@@ -378,7 +379,8 @@ def getHorizon(t, earth, moon):
     position = earth.at(t).observe(moon)   # at noontime (for daily average distance)
     distance = position.apparent().radec(epoch='date')[2]
     dist_km = distance.km
-    sdm = degrees(atan(1738.1/dist_km))   # equatorial radius of moon = 1738.1 km
+# OLD: sdm = degrees(atan(1738.1/dist_km))   # equatorial radius of moon = 1738.1 km
+    sdm = degrees(atan(1737.4/dist_km))   # volumetric mean radius of moon = 1737.4 km
     horizon = sdm + 0.5666667	# moon's equatorial radius + 34' (atmospheric refraction)
 
     return horizon
@@ -386,9 +388,9 @@ def getHorizon(t, earth, moon):
 def moonstate(mstate):
     # return the current moonstate (if known)
     out = '--:--'
-    if mstate == True:
+    if mstate == True:      # above horizon
         out = r'''\begin{tikzpicture}\draw (0,0) rectangle (12pt,4pt);\end{tikzpicture}'''
-    if mstate == False:
+    if mstate == False:     # below horizon
         out = r'''\rule{12Pt}{4Pt}'''
     return out
 
