@@ -47,6 +47,7 @@ from sfalmanac.lib import config as config
 #----------------------
 
 hour_of_day = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23]
+next_hour_of_day = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24]
 degree_sign= u'\N{DEGREE SIGN}'
 
 #----------------------
@@ -454,7 +455,8 @@ def mp_moonGHA(d, ts, earth, moon, round2seconds = False):  # used in sunmoontab
         decm[i] = fmtdeg(dec.degrees[i],2)
         degm[i] = dec.degrees[i]
         dist_km = distance.km[i]
-        HP = degrees(atan(6378.0/dist_km))	# radius of earth = 6378.0 km
+# OLD:  HP = degrees(atan(6378.0/dist_km))	# radius of earth = 6378.0 km
+        HP = degrees(atan(6371.0/dist_km))	# volumetric mean radius of earth = 6371.0 km
         HPm[i] = "{:0.1f}'".format(HP * 60)     # convert to minutes of arc
 
     # degm has been added for the sunmoontab function
@@ -463,17 +465,21 @@ def mp_moonGHA(d, ts, earth, moon, round2seconds = False):  # used in sunmoontab
 
     return gham, decm, degm, HPm, GHAupper, GHAlower, ghaSoD, ghaEoD
 
-def mp_moonVD(d0, d, ts, earth, moon):           # used in sunmoontab(m)
-    # first value required is from 23:30 on the previous day...
-    t0 = ts.ut1(d0.year, d0.month, d0.day, 23, 30, 0)
+def mp_moonVD(d00, d, ts, earth, moon):           # used in sunmoontab(m)
+# OLD:  # first value required is from 23:30 on the previous day...
+# OLD:  t0 = ts.ut1(d00.year, d00.month, d00.day, 23, 30, 0)
+    # first value required is from 00:00 on the current day...
+    t0 = ts.ut1(d.year, d.month, d.day, 0, 0, 0)
     pos0 = earth.at(t0).observe(moon)
     ra0 = pos0.apparent().radec(epoch='date')[0]
     dec0 = pos0.apparent().radec(epoch='date')[1]
     V0 = gha2deg(t0.gast, ra0.hours)
     D0 = dec0.degrees
 
-    # ...then 24 values at hourly intervals from 23:30 onwards
-    t = ts.ut1(d.year, d.month, d.day, hour_of_day, 30, 0)
+# OLD:  # ...then 24 values at hourly intervals from 23:30 onwards
+# OLD:  t = ts.ut1(d.year, d.month, d.day, hour_of_day, 30, 0)
+    # ...then 24 values at hourly intervals from 00:00 onwards
+    t = ts.ut1(d.year, d.month, d.day, next_hour_of_day, 0, 0)
     position = earth.at(t).observe(moon)
     ra = position.apparent().radec(epoch='date')[0]
     dec = position.apparent().radec(epoch='date')[1]
@@ -531,7 +537,8 @@ def mp_stellar_info(d, ts, spad, df, n):        # used in starstab
     eph = load(config.ephemeris[config.ephndx][0])	# load chosen ephemeris
     earth   = eph['earth']
 
-    t12 = ts.ut1(d.year, d.month, d.day, 12, 0, 0)  #calculate at noon
+    t00 = ts.ut1(d.year, d.month, d.day, 0, 0, 0)   #calculate at midnight
+    #t12 = ts.ut1(d.year, d.month, d.day, 12, 0, 0)  #calculate at noon
     out = []
 
     if n == 0: db = db1
@@ -547,7 +554,7 @@ def mp_stellar_info(d, ts, spad, df, n):        # used in starstab
         HIPnum = line[x1+1:]
 
         star = Star.from_dataframe(df.loc[int(HIPnum)])
-        astrometric = earth.at(t12).observe(star).apparent()
+        astrometric = earth.at(t00).observe(star).apparent()
         ra, dec, distance = astrometric.radec(epoch='date')
 
         sha  = fmtgha(0, ra.hours)
@@ -736,7 +743,6 @@ def getmoonstate(dt, lat, hemisph, ts, earth, moon):
 
     time00 = 0.0                        # 00000
     Hseeks = 0
-    i = 1 + config.lat.index(lat)   # index 0 is reserved to enable an explicit setting
     lats = '{:3.1f} {}'.format(abs(lat), hemisph)
     locn = Topos(lats, '0.0 E')
     t0 = ts.ut1(dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second)
@@ -765,7 +771,8 @@ def getHorizon(t, earth, moon):
     position = earth.at(t).observe(moon)   # at noontime (for daily average distance)
     distance = position.apparent().radec(epoch='date')[2]
     dist_km = distance.km
-    sdm = degrees(atan(1738.1/dist_km))   # equatorial radius of moon = 1738.1 km
+# OLD: sdm = degrees(atan(1738.1/dist_km))   # equatorial radius of moon = 1738.1 km
+    sdm = degrees(atan(1737.4/dist_km))   # volumetric mean radius of moon = 1737.4 km
     horizon = sdm + 0.5666667	# moon's equatorial radius + 34' (atmospheric refraction)
 
     return horizon
@@ -773,13 +780,13 @@ def getHorizon(t, earth, moon):
 def moonstate(mstate):
     # return the current moonstate (if known)
     out = '--:--'
-    if mstate == True:
+    if mstate == True:      # above horizon
         out = r'''\begin{tikzpicture}\draw (0,0) rectangle (12pt,4pt);\end{tikzpicture}'''
-    if mstate == False:
+    if mstate == False:     # below horizon
         out = r'''\rule{12Pt}{4Pt}'''
     return out
 
-def seek_moonset(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, earth, moon):
+def seek_moonset(t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon):
     # for the specified date & latitude ...
     # return -1 if there is NO MOONSET yesterday
     # return +1 if there is NO MOONSET tomorrow
@@ -788,10 +795,8 @@ def seek_moonset(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, eart
 
     time00 = 0.0                        # 00000
     Hseeks = 1
-#    config.moonHorizonSeeks += 1
     m_set_t = 0     # normal case: assume moonsets yesterday & tomorrow
 
-#    rise, sett, ris2, set2, fs = fetchMoonData(nxday, t1, t1noon, t2, i, lats, True, round2seconds)
     locn = Topos(lats, "0.0 E")
     horizon = getHorizon(t1noon, earth, moon)
     start00 = time()                    # 00000
@@ -803,8 +808,6 @@ def seek_moonset(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, eart
         m_set_t = +1    # if no moonset detected - it is after tomorrow
     else:
         Hseeks += 1
-#        config.moonHorizonSeeks += 1
-#        rise, sett, ris2, set2, fs = fetchMoonData(prday, t9, t9noon, t0, i, lats, True, round2seconds)
         locn = Topos(lats, "0.0 E")
         horizon = getHorizon(t9noon, earth, moon)
         start00 = time()                # 00000
@@ -817,7 +820,7 @@ def seek_moonset(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, eart
 
     return m_set_t, time00, Hseeks
 
-def seek_moonrise(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, earth, moon):
+def seek_moonrise(t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon):
     # for the specified date & latitude ...
     # return -1 if there is NO MOONRISE yesterday
     # return +1 if there is NO MOONRISE tomorrow
@@ -826,10 +829,8 @@ def seek_moonrise(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, ear
 
     time00 = 0.0                        # 00000
     Hseeks = 1
-#    config.moonHorizonSeeks += 1
     m_rise_t = 0    # normal case: assume moonrise yesterday & tomorrow
 
-#    rise, sett, ris2, set2, fs = fetchMoonData(nxday, t1, t1noon, t2, i, lats, True)
     locn = Topos(lats, "0.0 E")
     horizon = getHorizon(t1noon, earth, moon)
     start00 = time()                    # 00000
@@ -841,8 +842,6 @@ def seek_moonrise(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, ear
         m_rise_t = +1    # if no moonrise detected - it is after tomorrow
     else:
         Hseeks += 1
-#        config.moonHorizonSeeks += 1
-#        rise, sett, ris2, set2, fs = fetchMoonData(prday, t9, t9noon, t0, i, lats, True)
         locn = Topos(lats, "0.0 E")
         horizon = getHorizon(t9noon, earth, moon)
         start00 = time()                # 00000
@@ -855,10 +854,10 @@ def seek_moonrise(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, ear
 
     return m_rise_t, time00, Hseeks
 
-def moonset_no_rise(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, earth, moon):
+def moonset_no_rise(date, lat, t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon):
     # if moonset but no moonrise...
     msg = ""
-    n, t00, Hseeks = seek_moonrise(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, earth, moon)
+    n, t00, Hseeks = seek_moonrise(t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon)
     if n == 1:
         out = moonstate(False)      # moonrise "below horizon"
         ##msg = "below horizon (start)"
@@ -870,10 +869,10 @@ def moonset_no_rise(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i,
         out = r'''\raisebox{0.24ex}{\boldmath$\cdot\cdot$~\boldmath$\cdot\cdot$}'''
     return out, t00, Hseeks
 
-def moonrise_no_set(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, earth, moon):
+def moonrise_no_set(date, lat, t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon):
     # if moonrise but no moonset...
     msg = ""
-    n, t00, Hseeks = seek_moonset(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, ts, earth, moon)
+    n, t00, Hseeks = seek_moonset(t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon)
     if n == 1:
         out = moonstate(True)       # moonset "above horizon"
         ##msg = "above horizon (start)"
@@ -888,7 +887,7 @@ def moonrise_no_set(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i,
 # > > > > > > > > > > MULTIPROCESSING ENTRY POINT < < < < < < < < < <
 # > > > > > > > DO NOT WRITE TO config.py  (It's a copy!) < < < < < <
 
-def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by tables.py in twilighttab (section 2)
+def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by nautical.py in twilighttab (section 2)
     # - - - TIMES ARE ROUNDED TO MINUTES - - -
     # returns moonrise and moonset for the given dates and latitude:
     # rise day 1, rise day 2, rise day 3, set day 1, set day 2, set day 3
@@ -906,7 +905,6 @@ def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by tables.py in
     out = [None, None, None, None]
     ev1 = ['--:--','--:--','--:--','--:--','--:--','--:--']	# first event
     ev2 = ['--:--','--:--','--:--','--:--','--:--','--:--']	# second event on same day (rare)
-    i = 1 + config.lat.index(lat)   # index 0 is reserved to enable an explicit setting
 
     lats = "{:3.1f} {}".format(abs(lat), hemisph)
     locn = Topos(lats, "0.0 E")
@@ -929,6 +927,7 @@ def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by tables.py in
 
     t4 = ts.ut1(dt.year, dt.month, dt.day+4, dt.hour, dt.minute, dt.second)
 
+    # get the angle of the moon below the horizon at noontime (for daily average distance)
     t9noon = ts.ut1(dt.year, dt.month, dt.day, dt.hour-12, dt.minute, dt.second)
     t0noon = ts.ut1(dt.year, dt.month, dt.day, dt.hour+12, dt.minute, dt.second)
     t1noon = ts.ut1(dt.year, dt.month, dt.day+1, dt.hour+12, dt.minute, dt.second)
@@ -951,7 +950,7 @@ def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by tables.py in
     if ev1[0] == '--:--' and ev1[3] == '--:--':	# if neither moonrise nor moonset...
         Mseeks -= 1
         if mstate1 == None:
-            if moonstate != None:
+            if mstate0 != None:
                 mstate1 = mstate0        # get the last known moon state
             else:   # must search for the moon state...
                 mstate1, t00, iH = getmoonstate(dt, lat, hemisph, ts, earth, moon)	# ...get moon state if unknown
@@ -960,11 +959,11 @@ def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by tables.py in
         ev1[3] = moonstate(mstate1)
 
     elif ev1[0] == '--:--' and ev1[3] != '--:--':	# if moonset but no moonrise...
-        ev1[0], t00, iH = moonset_no_rise(d, lat, d9, t9, t9noon, t0, d1, t1, t1noon, t2, i, lats, ts, earth, moon)
+        ev1[0], t00, iH = moonset_no_rise(d, lat, t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon)
         timeAB += t00                   # 00000
 
     elif ev1[0] != '--:--' and ev1[3] == '--:--':	# if moonrise but no moonset...
-        ev1[3], t00, iH = moonrise_no_set(d, lat, d9, t9, t9noon, t0, d1, t1, t1noon, t2, i, lats, ts, earth, moon)
+        ev1[3], t00, iH = moonrise_no_set(d, lat, t9, t9noon, t0, t1, t1noon, t2, lats, ts, earth, moon)
         timeAB += t00                   # 00000
     Hseeks += iH
 #-----------------------------------------------------------
@@ -991,11 +990,11 @@ def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by tables.py in
         ev1[4] = moonstate(mstate2)
 
     elif ev1[1] == '--:--' and ev1[4] != '--:--':	# if moonset but no moonrise...
-        ev1[1], t00, iH = moonset_no_rise(d1, lat, d, t0, t0noon, t1, d2, t2, t2noon, t3, i, lats, ts, earth, moon)
+        ev1[1], t00, iH = moonset_no_rise(d1, lat, t0, t0noon, t1, t2, t2noon, t3, lats, ts, earth, moon)
         timeAB += t00                   # 00000
 
     elif ev1[1] != '--:--' and ev1[4] == '--:--':	# if moonrise but no moonset...
-        ev1[4], t00, iH = moonrise_no_set(d1, lat, d, t0, t0noon, t1, d2, t2, t2noon, t3, i, lats, ts, earth, moon)
+        ev1[4], t00, iH = moonrise_no_set(d1, lat, t0, t0noon, t1, t2, t2noon, t3, lats, ts, earth, moon)
         timeAB += t00                   # 00000
     Hseeks += iH
 #-----------------------------------------------------------
@@ -1022,11 +1021,11 @@ def mp_moonrise_set(d, lat, mstate0, hemisph, ts, spad):  # used by tables.py in
         ev1[5] = moonstate(mstate3)
 
     elif ev1[2] == '--:--' and ev1[5] != '--:--':	# if moonset but no moonrise...
-        ev1[2], t00, iH = moonset_no_rise(d2, lat, d1, t1, t1noon, t2, d3, t3, t3noon, t4, i, lats, ts, earth, moon)
+        ev1[2], t00, iH = moonset_no_rise(d2, lat, t1, t1noon, t2, t3, t3noon, t4, lats, ts, earth, moon)
         timeAB += t00                   # 00000
 
     elif ev1[2] != '--:--' and ev1[5] == '--:--':	# if moonrise but no moonset...
-        ev1[5], t00, iH = moonrise_no_set(d2, lat, d1, t1, t1noon, t2, d3, t3, t3noon, t4, i, lats, ts, earth, moon)
+        ev1[5], t00, iH = moonrise_no_set(d2, lat, t1, t1noon, t2, t3, t3noon, t4, lats, ts, earth, moon)
         timeAB += t00                   # 00000
     Hseeks += iH
 #-----------------------------------------------------------
