@@ -56,12 +56,12 @@ if config.MULTIpr:  # in multi-processing mode ...
     import multiprocessing as mp
     from functools import partial
     # ... following is still required for SINGLE-PROCESSING (in multi-processing mode):
-    from sfalmanac.lib.alma_skyfield import ariesGHA, venusGHA, marsGHA, jupiterGHA, saturnGHA, sunGHA, moonGHA, moonVD, sunSD, moonSD, vdm_Venus, vdm_Mars, vdm_Jupiter, vdm_Saturn, ariestransit, stellar_info, planetstransit, moonage, moonphase, equation_of_time, getParams, find_new_moon
+    from sfalmanac.lib.alma_skyfield import ariesGHA, venusGHA, marsGHA, jupiterGHA, saturnGHA, sunGHA, moonGHA, moonVD, sunSD, moonSD, vdm_Venus, vdm_Mars, vdm_Jupiter, vdm_Saturn, ariestransit, stellar_info, planetstransit, moonage, moonphase, equation_of_time, getDUT1, find_new_moon
     # ... following is required for MULTI-PROCESSING:
     from sfalmanac.lib.mp_nautical import mp_twilight, mp_moonrise_set, mp_planetstransit, hor_parallax, mp_planetGHA, mp_sunmoon
 else:
     # ... following is required for SINGLE-PROCESSING:
-    from sfalmanac.lib.alma_skyfield import ariesGHA, venusGHA, marsGHA, jupiterGHA, saturnGHA, sunGHA, moonGHA, moonVD, sunSD, moonSD, vdm_Venus, vdm_Mars, vdm_Jupiter, vdm_Saturn, ariestransit, stellar_info, planetstransit, twilight, moonrise_set, moonage, moonphase, equation_of_time, getParams, find_new_moon
+    from sfalmanac.lib.alma_skyfield import ariesGHA, venusGHA, marsGHA, jupiterGHA, saturnGHA, sunGHA, moonGHA, moonVD, sunSD, moonSD, vdm_Venus, vdm_Mars, vdm_Jupiter, vdm_Saturn, ariestransit, stellar_info, planetstransit, twilight, moonrise_set, moonage, moonphase, equation_of_time, getDUT1, find_new_moon
 
 
 UpperLists = [[], [], []]    # moon GHA per hour for 3 days
@@ -71,6 +71,14 @@ LowerLists = [[], [], []]    # moon colong GHA per hour for 3 days
 #   internal methods
 #----------------------
 
+def fmtdate(d):
+    if config.pgsz == 'Letter': return d.strftime("%m/%d/%Y")
+    return d.strftime("%d.%m.%Y")
+
+def fmtdates(d1,d2):
+    if config.pgsz == 'Letter': return d1.strftime("%m/%d/%Y") + " - " + d2.strftime("%m/%d/%Y")
+    return d1.strftime("%d.%m.%Y") + " - " + d2.strftime("%d.%m.%Y")
+
 def buildUPlists(n, ghaSoD, ghaPerHour, ghaEoD):
     # build list of hourly GHA values with modified start and end time to
     #  account for rounding times to the minute where 23:59:>30 rounds up
@@ -355,13 +363,17 @@ def planetstab(date, ts, spad):
                 tab = tab + line + lineterminator
                 h += 1
 
-        RAc_v, Dc_v = vdm_Venus(date)
+        mag_v, mag_m, mag_j, mag_s = magnitudes(date)   # magnitudes from Ephem
+        RAc_v, Dc_v, mag_v = vdm_Venus(date)
         RAc_m, Dc_m = vdm_Mars(date)
-        RAc_j, Dc_j = vdm_Jupiter(date)
+        RAc_j, Dc_j, mag_j = vdm_Jupiter(date)
         RAc_s, Dc_s = vdm_Saturn(date)
-        mag_v, mag_m, mag_j, mag_s = magnitudes(date)
         tab = tab + r'''\hline
-\multicolumn{{2}}{{|c|}}{{\rule{{0pt}}{{2.4ex}}Mer.pass.:{}}} & \multicolumn{{2}}{{c|}}{{v{} d{} m{}}} & \multicolumn{{2}}{{c|}}{{v{} d{} m{}}} & \multicolumn{{2}}{{c|}}{{v{} d{} m{}}} & \multicolumn{{2}}{{c|}}{{v{} d{} m{}}}\\
+\multicolumn{{2}}{{|c|}}{{\rule{{0pt}}{{2.4ex}}Mer.pass. {}}} & 
+\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}}} & 
+\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}}} & 
+\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}}} & 
+\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}}}\\
 \hline
 \multicolumn{{10}}{{c}}{{}}\\
 '''.format(ariestransit(date+timedelta(days=1)),RAc_v,Dc_v,mag_v,RAc_m,Dc_m,mag_m,RAc_j,Dc_j,mag_j,RAc_s,Dc_s,mag_s)
@@ -478,17 +490,17 @@ def planetstabm(date, ts, spad):
                 tab = tab + line
                 h += 1
 
-        RAc_v, Dc_v = vdm_Venus(date)
+        mag_v, mag_m, mag_j, mag_s = magnitudes(date)   # magnitudes from Ephem
+        RAc_v, Dc_v, mag_v = vdm_Venus(date)
         RAc_m, Dc_m = vdm_Mars(date)
-        RAc_j, Dc_j = vdm_Jupiter(date)
+        RAc_j, Dc_j, mag_j = vdm_Jupiter(date)
         RAc_s, Dc_s = vdm_Saturn(date)
-        mag_v, mag_m, mag_j, mag_s = magnitudes(date)
         tab = tab + r'''\cmidrule{{1-2}} \cmidrule{{4-5}} \cmidrule{{7-8}} \cmidrule{{10-11}} \cmidrule{{13-14}}
-\multicolumn{{2}}{{c}}{{\footnotesize{{Mer.pass.:{}}}}} && 
-\multicolumn{{2}}{{c}}{{\footnotesize{{v{} d{} m{}}}}} && 
-\multicolumn{{2}}{{c}}{{\footnotesize{{v{} d{} m{}}}}} && 
-\multicolumn{{2}}{{c}}{{\footnotesize{{v{} d{} m{}}}}} && 
-\multicolumn{{2}}{{c}}{{\footnotesize{{v{} d{} m{}}}}}\\
+\multicolumn{{2}}{{c}}{{\footnotesize{{Mer.pass. {}}}}} && 
+\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}}}}} && 
+\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}}}}} && 
+\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}}}}} && 
+\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}}}}}\\
 \cmidrule{{1-2}} \cmidrule{{4-5}} \cmidrule{{7-8}} \cmidrule{{10-11}} \cmidrule{{13-14}}
 '''.format(ariestransit(date+timedelta(days=1)),RAc_v,Dc_v,mag_v,RAc_m,Dc_m,mag_m,RAc_j,Dc_j,mag_j,RAc_s,Dc_s,mag_s)
         if n < 2:
@@ -629,9 +641,10 @@ def sunmoontab(date, ts, spad):
     n = 0
     while n < 3:
         tab = tab + r'''\hline
-\multicolumn{{1}}{{|c|}}{{\rule{{0pt}}{{2.6ex}}\textbf{{{}}}}} &\multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c|}}{{\textbf{{Dec}}}}  & \multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c}}{{\textbf{{\(\nu\)}}}} & \multicolumn{{1}}{{c}}{{\textbf{{Dec}}}} & \multicolumn{{1}}{{c}}{{\textbf{{d}}}} & \multicolumn{{1}}{{c|}}{{\textbf{{HP}}}}\\
+\multicolumn{{1}}{{|c|}}{{\rule{{0pt}}{{2.6ex}}\textbf{{{}}}}} &\multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c|}}{{\textbf{{Dec}}}}  & \multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c}}{{\(\nu\)}} & \multicolumn{{1}}{{c}}{{\textbf{{Dec}}}} & \multicolumn{{1}}{{c}}{{\textit{{d}}}} & \multicolumn{{1}}{{c|}}{{\textbf{{HP}}}}\\
 \hline\rule{{0pt}}{{2.6ex}}\noindent
 '''.format(date.strftime("%a"))
+        # note: inline math mode is used to typeset the greek character 'nu'
 
         if config.MULTIpr and config.WINpf:
             ghas = sunmoonlist[n][0]
@@ -702,7 +715,7 @@ def sunmoontab(date, ts, spad):
         sds, dsm = sunSD(date)
         sdmm = moonSD(date)
         tab = tab + r'''\hline
-\rule{{0pt}}{{2.4ex}} & \multicolumn{{1}}{{c}}{{SD.={}}} & \multicolumn{{1}}{{c|}}{{d={}}} & \multicolumn{{5}}{{c|}}{{S.D.={}}}\\
+\rule{{0pt}}{{2.4ex}} & \multicolumn{{1}}{{c}}{{SD = {}$'$}} & \multicolumn{{1}}{{c|}}{{\textit{{d}} = {}$'$}} & \multicolumn{{5}}{{c|}}{{SD = {}$'$}}\\
 \hline
 '''.format(sds,dsm,sdmm)
         if n < 2:
@@ -736,7 +749,7 @@ def sunmoontabm(date, ts, spad):
     n = 0
     while n < 3:
         tab = tab + r'''
-\multicolumn{{1}}{{c}}{{\textbf{{{}}}}} & \multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c}}{{\textbf{{Dec}}}} & & \multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c}}{{\textbf{{\(\nu\)}}}} & \multicolumn{{1}}{{c}}{{\textbf{{Dec}}}} & \multicolumn{{1}}{{c}}{{\textbf{{d}}}} & \multicolumn{{1}}{{c}}{{\textbf{{HP}}}}\\
+\multicolumn{{1}}{{c}}{{\textbf{{{}}}}} & \multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c}}{{\textbf{{Dec}}}} & & \multicolumn{{1}}{{c}}{{\textbf{{GHA}}}} & \multicolumn{{1}}{{c}}{{\(\nu\)}} & \multicolumn{{1}}{{c}}{{\textbf{{Dec}}}} & \multicolumn{{1}}{{c}}{{\textit{{d}}}} & \multicolumn{{1}}{{c}}{{\textbf{{HP}}}}\\
 '''.format(date.strftime("%a"))
 
         if config.MULTIpr and config.WINpf:
@@ -813,8 +826,8 @@ def sunmoontabm(date, ts, spad):
         sds, dsm = sunSD(date)
         sdmm = moonSD(date)
         tab = tab + r'''\cmidrule{{2-3}} \cmidrule{{5-9}}
-\multicolumn{{1}}{{c}}{{}} & \multicolumn{{1}}{{c}}{{\footnotesize{{SD.={}}}}} & 
-\multicolumn{{1}}{{c}}{{\footnotesize{{d={}}}}} && \multicolumn{{5}}{{c}}{{\footnotesize{{S.D.={}}}}}\\
+\multicolumn{{1}}{{c}}{{}} & \multicolumn{{1}}{{c}}{{\footnotesize{{SD = {}$'$}}}} & 
+\multicolumn{{1}}{{c}}{{\footnotesize{{\textit{{d}} = {}$'$}}}} && \multicolumn{{5}}{{c}}{{\footnotesize{{SD = {}$'$}}}}\\
 \cmidrule{{2-3}} \cmidrule{{5-9}}
 '''.format(sds,dsm,sdmm)
         if n < 2:
@@ -832,7 +845,6 @@ def sunmoontabm(date, ts, spad):
 # >>>>>>>>>>>>>>>>>>>>>>>>
 # create a list of 'moon above/below horizon' states per Latitude...
 #    None = unknown; True = above horizon (visible); False = below horizon (not visible)
-#    moonvisible[0] is not linked to a latitude but a manual override
 # The moon above/below status is stored at 3-day intervals, i.e. when multiprocessing "1st day",
 #    the previous day's status is stored here (except on the first day to be processed).
 #    Multiprocessing does not confuse the states as every three days it waits for all data.
@@ -871,7 +883,7 @@ def twilighttab(date, ts, spad, dfcm):
         listmoon = pool.starmap(partial_func2, data, 1)   # RECOMMENDED: chunksize = 1
         for k in range(len(listmoon)):
             tuple_seeks = listmoon[k][-1]
-            config.moonDataSeeks    += tuple_seeks[0]   # count of moonrise ot set seeks
+            config.moonDataSeeks    += tuple_seeks[0]   # count of moonrise or set seeks
             config.moonHorizonSeeks += tuple_seeks[1]   # count of horizon seeks
             moonvisible[k] = tuple_seeks[2]             # updated moon state
             del listmoon[k][-1]
@@ -1137,15 +1149,20 @@ def twilighttab(date, ts, spad, dfcm):
 #   page preparation
 #----------------------
 
-def doublepage(date, page1, pnum, ts, spad, dfcm):
+def doublepage(date, page1, ts, spad, dfcm):
     # creates a doublepage (3 days) of the nautical almanac
 
     # time delta values for the initial date&time...
-    dut1, deltat = getParams(date)
+    dut1, deltat = getDUT1(date)
     timeDUT1 = r"DUT1 = UT1-UTC = {:+.4f} sec\quad$\Delta$T = TT-UT1 = {:+.4f} sec".format(dut1, deltat)
 
-    dateZ = date + timedelta(days=pnum-1)       # last day
     find_new_moon(date)     # required for 'moonage' and 'equation_of_time"
+    #from alma_skyfield import PreviousNewMoon, PreviousFullMoon, NextNewMoon, NextFullMoon
+    #print("previous  new moon: %s" %PreviousNewMoon)
+    #print("previous full moon: %s" %PreviousFullMoon)
+    #print("next      new moon: %s" %NextNewMoon)
+    #print("next     full moon: %s" %NextFullMoon)
+
     page = ''
     if not(page1):
         page = r'''
@@ -1203,7 +1220,8 @@ def doublepage(date, page1, pnum, ts, spad, dfcm):
     return page
 
 
-def pages(first_day, pnum, ts, spad, dfcm):
+def pages(first_day, dtp, ts, spad, dfcm):
+    # dtp = 0 if for entire year; = -1 if for entire month; else days to print
 
     if config.MULTIpr:
         # Windows & macOS defaults to "spawn"; Unix to "fork"
@@ -1214,27 +1232,60 @@ def pages(first_day, pnum, ts, spad, dfcm):
         global pool
         pool = mp.Pool(n)   # start 8 max. worker processes
 
-    # make 'pnum' doublepages beginning with first_day
     out = ''
     page1 = True
     pmth = ''
-    for i in range(pnum):
-        if pnum == 122:	# if Full Almanac for a year...
-            cmth = first_day.strftime("%b ")
+    dpp = 3         # 3 days per page
+    day1 = first_day
+
+    if dtp == 0:        # if entire year
+        year = first_day.year
+        yr = year
+        while year == yr:
+            cmth = day1.strftime("%b ")
+            day3 = day1 + timedelta(days=2)
             if cmth != pmth:
-                print()		# progress indicator - next month
+                print() # progress indicator - next month
                 #print(cmth, end='')
                 sys.stdout.write(cmth)	# next month
                 sys.stdout.flush()
+                pmth = cmth
             else:
                 sys.stdout.write('.')	# progress indicator
                 sys.stdout.flush()
-            pmth = cmth
-        out = out + doublepage(first_day,page1,pnum,ts,spad,dfcm)
-        page1 = False
-        first_day += timedelta(days=3)
-    if pnum == 122:	# if Full Almanac for a year...
-        print()		# newline to terminate progress indicator
+            out += doublepage(day1,page1,ts,spad,dfcm)
+            page1 = False
+            day1 += timedelta(days=3)
+            year = day1.year
+    elif dtp == -1:     # if entire month
+        mth = first_day.month
+        m = mth
+        while mth == m:
+            cmth = day1.strftime("%b ")
+            day3 = day1 + timedelta(days=2)
+            if cmth != pmth:
+                print() # progress indicator - next month
+                #print(cmth, end='')
+                sys.stdout.write(cmth)	# next month
+                sys.stdout.flush()
+                pmth = cmth
+            else:
+                sys.stdout.write('.')	# progress indicator
+                sys.stdout.flush()
+            out += doublepage(day1,page1,ts,spad,dfcm)
+            page1 = False
+            day1 += timedelta(days=3)
+            mth = day1.month
+    else:           # print 'dtp' days beginning with first_day
+        i = dtp   # don't decrement dtp
+        while i > 0:
+            out += doublepage(day1,page1,ts,spad,dfcm)
+            page1 = False
+            i -= 3
+            day1 += timedelta(days=3)
+
+    if dtp <= 0:        # if Full Almanac for a whole month/year...
+        print("\n")		# 2 x newline to terminate progress indicator
 
     if config.MULTIpr:
         pool.close()    # close all worker processes
@@ -1246,7 +1297,8 @@ def pages(first_day, pnum, ts, spad, dfcm):
 #   external entry point
 #--------------------------
 
-def almanac(first_day, pagenum, ts, spad, df180, df360, dfcm):
+def almanac(first_day, dtp, ts, spad, df180, df360, dfcm):
+    # dtp = 0 if for entire year; = -1 if for entire month; else days to print
 
     # make almanac starting from first_day
     global tm, bm, oddim, oddom
@@ -1309,7 +1361,8 @@ def almanac(first_day, pagenum, ts, spad, df180, df360, dfcm):
     alm = alm + r'''
 %\usepackage[utf8]{inputenc}
 \usepackage[english]{babel}
-\usepackage{fontenc}'''
+\usepackage{fontenc}
+\usepackage{enumitem} % used to customize the {description} environment'''
 
     # to troubleshoot add "showframe, verbose," below:
     alm = alm + r'''
@@ -1361,16 +1414,26 @@ def almanac(first_day, pagenum, ts, spad, df180, df360, dfcm):
     alm = alm + r'''[{}]
     \textsc{{\huge The Nautical Almanac}}\\[{}]'''.format(vsep1,vsep2)
 
-    if pagenum == 122:
+    if dtp == 0:
         alm = alm + r'''
     \HRule \\[0.5cm]
     {{ \Huge \bfseries {}}}\\[0.2cm]
     \HRule \\'''.format(year)
+    elif dtp == -1:
+        alm = alm + r'''
+    \HRule \\[0.5cm]
+    {{ \Huge \bfseries {}}}\\[0.2cm]
+    \HRule \\'''.format(first_day.strftime("%B %Y"))
+    elif dtp > 1:
+        alm = alm + r'''
+    \HRule \\[0.5cm]
+    {{ \Huge \bfseries {}}}\\[0.2cm]
+    \HRule \\'''.format(fmtdates(first_day,first_day+timedelta(days=dtp-1)))
     else:
         alm = alm + r'''
     \HRule \\[0.5cm]
-    {{ \Huge \bfseries from {}.{}.{}}}\\[0.2cm]
-    \HRule \\'''.format(day,mth,year)
+    {{ \Huge \bfseries {}}}\\[0.2cm]
+    \HRule \\'''.format(fmtdate(first_day))
 
     alm = alm + r'''
     \begin{center}\begin{tabular}[t]{rl}
@@ -1382,16 +1445,16 @@ def almanac(first_day, pagenum, ts, spad, df180, df360, dfcm):
     {\large \today}
     \HRule \\[0.2cm]
     \end{center}
-    \begin{description}\footnotesize
+    \begin{description}[leftmargin=5.5em,style=nextline]\footnotesize
     \item[Disclaimer:] These are computer generated tables - use them at your own risk.
     The accuracy has been randomly checked with JPL HORIZONS System, but cannot be guaranteed.
-    This means I cannot be held liable if you get lost on the oceans because of errors in this publication.
+    The author claims no liability for any consequences arising from use of these tables.
     Besides, this publication only contains the 'daily pages' of the Nautical Almanac: an official version of the Nautical Almanac is indispensable.
     \end{description}
 \end{titlepage}
 \restoregeometry    % so it does not affect the rest of the pages'''
 
-    alm = alm + pages(first_day,pagenum,ts,spad,dfcm)
+    alm = alm + pages(first_day,dtp,ts,spad,dfcm)
     alm = alm + '''
 \end{document}'''
     return alm
\ No newline at end of file
